summaryrefslogtreecommitdiff
path: root/gdb/ia64-vms-tdep.c
diff options
context:
space:
mode:
authorJan Kratochvil <jan.kratochvil@redhat.com>2012-03-08 19:08:09 +0000
committerJan Kratochvil <jan.kratochvil@redhat.com>2012-03-08 19:08:09 +0000
commit63605861f505c8b5830856c8714491945d11a29c (patch)
treebbf88aa6040cc9a95957a59913ea660222f1ff15 /gdb/ia64-vms-tdep.c
parent6aa1a3d2aa879e3c90cfb7ba6f092248e9b3d14f (diff)
downloadgdb-63605861f505c8b5830856c8714491945d11a29c.tar.gz
gdb/
* libunwind-frame.c: Rename to ... * ia64-libunwind-tdep.c: ... here. * libunwind-frame.h: Rename to ... * ia64-libunwind-tdep.h: ... here. * Makefile.in (HFILES_NO_SRCDIR): Rename libunwind-frame.h to ia64-libunwind-tdep.h. (ALLDEPFILES): Rename libunwind-frame.c to ia64-libunwind-tdep.c. * README (--with-libunwind): Rename to ... (--with-libunwind-ia64): ... here, note it is ia64 specific now. * config.in: Regenerate. * configure: Regenerate. * configure.ac: New option --with-libunwind-ia64, make the AS_HELP_STRING ia64 specific. Deprecate option --with-libunwind. Remove AC_DEFINE for HAVE_LIBUNWIND. * ia64-libunwind-tdep.c: Make the file top comment ia64 specific. Rename libunwind-frame.h #include to ia64-libunwind-tdep.h. Rename libunwind-frame in the general comment. * ia64-libunwind-tdep.h: Make the file top comment ia64 specific. Rename symbol LIBUNWIND_FRAME_H to IA64_TDEP_LIBUNWIND_FRAME_H. Move forward declarations inside #ifndef. Rename libunwind-frame in the general comment. * ia64-tdep.c: Rename libunwind-frame.h #include to ia64-libunwind-tdep.h. (ia64_gdb2uw_regnum, ia64_uw2gdb_regnum, ia64_is_fpreg) (ia64_libunwind_descr): Rename libunwind-frame to ia64-libunwind-tdep in these function comments. * ia64-tdep.h: Rename libunwind-frame.h #include to ia64-libunwind-tdep.h. * ia64-vms-tdep.c (ia64_vms_libunwind_descr): Rename libunwind-frame to ia64-libunwind-tdep in that data comment.
Diffstat (limited to 'gdb/ia64-vms-tdep.c')
-rw-r--r--gdb/ia64-vms-tdep.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gdb/ia64-vms-tdep.c b/gdb/ia64-vms-tdep.c
index 66920b11c35..09238fcb3d1 100644
--- a/gdb/ia64-vms-tdep.c
+++ b/gdb/ia64-vms-tdep.c
@@ -123,8 +123,8 @@ ia64_vms_get_dyn_info_list (unw_addr_space_t as,
static unw_accessors_t ia64_vms_unw_accessors;
static unw_accessors_t ia64_vms_unw_rse_accessors;
-/* Set of ia64 gdb libunwind-frame callbacks and data for generic
- libunwind-frame code to use. */
+/* Set of ia64-libunwind-tdep gdb callbacks and data for generic
+ ia64-libunwind-tdep code to use. */
static struct libunwind_descr ia64_vms_libunwind_descr;
#endif /* HAVE_LIBUNWIND_IA64_H */